package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(L``````````0```````
M`+%```````!``#@`"`!``!<`%@````8````$`````````$``````````0```
M``````!``````````<`````````!P``````````(`````P````0````````"
M``````````(``````````@``````````&``````````8``````````$````!
M````!0```````````````````````````````````````)Y@````````GF``
M```````0``````$````&````````J[@```````"[N````````+NX````````
M!,`````````5*````````!```````@````8```````"KX````````+O@````
M````N^`````````!H`````````&@``````````AD=.50````!````````)E`
M````````F4````````"90`````````"\`````````+P`````````!&1TY5$`
M```&````````````````````````````````````````````````````````
M```````09'3E4@````0```````"KN````````+NX````````N[@````````$
M2`````````1(``````````$O;&EB+VQD+6UU<VPM<S,Y,'@N<V\N,0`````1
M````3`````(````'201`"0@`A9KH`(2*012.2`````````!,````4````%0`
M``!5````6@```%L```!<`````````%X``````````````%\```!@````80``
M````````?)I_:@[OT^HM1][.']_%;[:;Q2X.\8VX?-1DU`[D_R$<6''98&RA
M^BP_Y<)OBP&R`<9'XGR2X[O2/,-59LRO9]-P!XCLU45#[=MB,YN<J7\*`J?A
M2?O@HP```````````````````````````````````````````P``!P``````
M`!BH```````````````,$@````````````````````````````''$@``````
M```````````````````````4$0````````````````````````````'M$0``
M``````````````````````````%I$@`````````````````````````````;
M$@````````````````````````````&F$@``````````````````````````
M```C$@`````````````````````````````J$@``````````````````````
M``````'Z$@````````````````````````````&R$@``````````````````
M```````````S(`````````````````````````````-"(0``````````````
M``````````````!+$@````````````````````````````!1$@``````````
M``````````````````,($@````````````````````````````+Y$@``````
M``````````````````````)_$@````````````````````````````!8$@``
M``````````````````````````(@$@````````````````````````````!?
M$@````````````````````````````*T$@``````````````````````````
M``!F$@````````````````````````````!N(```````````````````````
M``````""$@````````````````````````````*=$@``````````````````
M``````````"*$@````````````````````````````"0$@``````````````
M``````````````"9(`````````````````````````````+R$@``````````
M``````````````````"U$@````````````````````````````"Z$@``````
M``````````````````````(+$0````````````````````````````*[$@``
M``````````````````````````)-$@````````````````````````````,8
M$@````````````````````````````(_$@``````````````````````````
M``-^$@````````````````````````````+&$0``````````````````````
M``````-!$0````````````````````````````)Q$@``````````````````
M``````````,N$@````````````````````````````-#$0``````````````
M``````````````#!$@````````````````````````````,F$@``````````
M``````````````````%W$@````````````````````````````#*(@``````
M``````````````````````#9(`````````````````````````````#O$@``
M``````````````````````````+J$@````````````````````````````)=
M$@````````````````````````````#T$@``````````````````````````
M``#Z(`````````````````````````````*H$@``````````````````````
M``````$4$@````````````````````````````&7$@``````````````````
M``````````$9$@````````````````````````````*-$@``````````````
M``````````````&&$@````````````````````````````$?$@``````````
M``````````````````$P$@````````````````````````````(;$@``````
M``````````````````````"+$@````````````````````````````(L$@``
M``````````````````````````)F$@````````````````````````````,?
M$@````````````````````````````$V$@``````````````````````````
M``,0$@````````````````````````````%*$@``````````````````````
M``````(6$@````````````````````````````'5$@``````````````````
M``````````%1$@````````````````````````````-`(0``````````````
M``````````````%B$@````````````````````````````,[$@``"0``````
M`"!P`````````DP```'G$@``"@```````%FP``````````(```/`$@``"0``
M`````$LP````````"?8```0V$@``"0```````%CH`````````&X```.=$@``
M"0```````$38``````````8```//$@``!P```````!BH``````````(```/C
M$@``"0```````%4H`````````[P```0I$@``"0```````$3@`````````>P`
M``-2$```%````````,!X``````````````.N$@``"0```````$IX````````
M`+(```/-$@``"0```````$,@`````````#P```/5$@``"0```````$G`````
M`````'(```0#$@``"0```````$;0`````````"(```->$```%````````-#@
M``````````````-C$@``"0```````"+P`````````#0```00$@``"0``````
M`$;X`````````2P```/Y$0``$P```````,!P``````````@```-+$```$P``
M`````,!X``````````````-7$@``"0```````"+```````````````-L$@``
M"0```````$HX`````````#H```.'$@``"0```````$/``````````1@```0<
M$@``"0```````$@H`````````98`;&EB<&5R;"YS;P!O<&5N9&ER`'-T9&5R
M<@!R96%L;&]C`&%C8V5S<P!S;G!R:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?
M:6YF;P!L<V5E:P!G971P:60`;65M<V5T`'5N;&EN:P!M96UM;W9E`%]*=E]2
M96=I<W1E<D-L87-S97,`<W1R;F-M<`!L<W1A=`!C;&]S961I<@!?251-7V1E
M<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S='(`<F5A9&QI;FL`7U]C
M>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`8VQO<V4`
M7TE435]R96=I<W1E<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?97)R;F]?
M;&]C871I;VX`;6MD:7(`<'1H<F5A9%]G971S<&5C:69I8P!M96UC<'D`7U]S
M=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T
M7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S
M=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA
M9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O
M<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?
M<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O
M;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P
M97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F,N;75S;"US,SDP>"YS;RXQ
M`&9P<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`')E861D:7(`<W!R:6YT
M9@!S=')C:'(`<W1R=&]K`'-T<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?
M96YV:7)O;@!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!?<W1A<G1?8P!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`
M<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D
M:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/
M5`!M>5]P87)?<&P`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]I;FET
M7V5N=@!P87)?9FEN9'!R;V<`<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R;#4O
M8V]R95]P97)L+T-/4D4`````````OW@`````````#````````"!P````````
MOY``````````#````````%FP````````O[``````````#````````!BH````
M````P```````````#````````,``````````P`@`````````#````````%Q0
M````````P!``````````#````````%HH````````P"``````````#```````
M`%L4````````P"@`````````#````````%L8````````P#``````````#```
M`````%Q6````````P#@`````````#````````%IZ````````P$``````````
M#````````%Q>````````P%``````````#````````%QB````````P%@`````
M````#````````%QH````````P'``````````#````````%T*````````OX``
M```$````"@``````````````````OX@````%````"@``````````````````
MOY@````-````"@``````````````````OZ`````9````"@``````````````
M````OZ@````>````"@``````````````````O[@````B````"@``````````
M````````O\`````H````"@``````````````````O\@````L````"@``````
M````````````O]`````P````"@``````````````````O]@````Q````"@``
M````````````````O^`````V````"@``````````````````O^@````[````
M"@``````````````````O_`````\````"@``````````````````O_@```!!
M````"@``````````````````O9@````"````"P``````````````````O:``
M```#````"P``````````````````O:@````&````"P``````````````````
MO;`````'````"P``````````````````O;@````(````"P``````````````
M````O<`````)````"P``````````````````O<@````*````"P``````````
M````````O=`````+````"P``````````````````O=@````,````"P``````
M````````````O>`````-````"P``````````````````O>@````/````"P``
M````````````````O?`````0````"P``````````````````O?@````1````
M"P``````````````````O@`````2````"P``````````````````O@@````3
M````"P``````````````````OA`````4````"P``````````````````OA@`
M```5````"P``````````````````OB`````6````"P``````````````````
MOB@````7````"P``````````````````OC`````8````"P``````````````
M````OC@````:````"P``````````````````OD`````;````"P``````````
M````````OD@````<````"P``````````````````OE`````=````"P``````
M````````````OE@````?````"P``````````````````OF`````@````"P``
M````````````````OF@````A````"P``````````````````OG`````C````
M"P``````````````````OG@````D````"P``````````````````OH`````E
M````"P``````````````````OH@````F````"P``````````````````OI``
M```G````"P``````````````````OI@````J````"P``````````````````
MOJ`````K````"P``````````````````OJ@````M````"P``````````````
M````OK`````N````"P``````````````````OK@````O````"P``````````
M````````OL`````P````"P``````````````````OL@````Q````"P``````
M````````````OM`````R````"P``````````````````OM@````S````"P``
M````````````````ON`````T````"P``````````````````ON@````U````
M"P``````````````````OO`````W````"P``````````````````OO@````X
M````"P``````````````````OP`````Y````"P``````````````````OP@`
M```Z````"P``````````````````OQ`````]````"P``````````````````
MOQ@````^````"P``````````````````OR`````_````"P``````````````
M````OR@```!`````"P``````````````````OS````!"````"P``````````
M````````OS@```!#````"P``````````````````OT````!$````"P``````
M````````````OT@```!%````"P``````````````````OU````!&````"P``
M````````````````OU@```!'````"P``````````````````OV````!(````
M"P``````````````````OV@```!)````"P``````````````````OW````!+
M````"P``````````Z^_P<``DN00`#Z?[_V#C`/```"3`Y0``!=K`Y0``($OK
M[_$0``0'_N,0\#@`),`0``!25=('\#`0".,0$!``!`?Q!P`'``<`P!```%)4
MXQ`0```$!_$-$.,0$`P`%,#T____Y0````#`$```4DCC$!````0'\0T0XQ`0
M#``4P/3____5````&,`0``!2/.,0$```!`?Q#1#C$!`,`!3`]/___\4````P
MP!```%(PXQ`0```$!_$-$.,0$`P`%,#T____M0```$C`$```4B3C$!````0'
M\0T0XQ`0#``4P/3___^E````8,`0``!2&.,0$```!`?Q#1#C$!`,`!3`]/__
M_Y4```!XP!```%(,XQ`0```$!_$-$.,0$`P`%,#T____A0```)#`$```4@#C
M$!````0'\0T0XQ`0#``4P/3___]U````J,`0``!1].,0$```!`?Q#1#C$!`,
M`!3`]/___V4```#`P!```%'HXQ`0```$!_$-$.,0$`P`%,#T____50```-C`
M$```4=SC$!````0'\0T0XQ`0#``4P/3___]%````\,`0``!1T.,0$```!`?Q
M#1#C$!`,`!3`]/___S4```$(P!```%'$XQ`0```$!_$-$.,0$`P`%,#T____
M)0```2#`$```4;CC$!````0'\0T0XQ`0#``4P/3___\5```!.,`0``!1K.,0
M$```!`?Q#1#C$!`,`!3`]/___P4```%0P!```%&@XQ`0```$!_$-$.,0$`P`
M%,#T___^]0```6C`$```493C$!````0'\0T0XQ`0#``4P/3___[E```!@,`0
M``!1B.,0$```!`?Q#1#C$!`,`!3`]/___M4```&8P!```%%\XQ`0```$!_$-
M$.,0$`P`%,#T___^Q0```;#`$```47#C$!````0'\0T0XQ`0#``4P/3___ZU
M```!R,`0``!19.,0$```!`?Q#1#C$!`,`!3`]/___J4```'@P!```%%8XQ`0
M```$!_$-$.,0$`P`%,#T___^E0```?C`$```44SC$!````0'\0T0XQ`0#``4
MP/3___Z%```"$,`0``!10.,0$```!`?Q#1#C$!`,`!3`]/___G4```(HP!``
M`%$TXQ`0```$!_$-$.,0$`P`%,#T___^90```D#`$```42CC$!````0'\0T0
MXQ`0#``4P/3___Y5```"6,`0``!1'.,0$```!`?Q#1#C$!`,`!3`]/___D4`
M``)PP!```%$0XQ`0```$!_$-$.,0$`P`%,#T___^-0```HC`$```403C$!``
M``0'\0T0XQ`0#``4P/3___XE```"H,`0``!0^.,0$```!`?Q#1#C$!`,`!3`
M]/___A4```*XP!```%#LXQ`0```$!_$-$.,0$`P`%,#T___^!0```M#`$```
M4.#C$!````0'\0T0XQ`0#``4P/3___WU```"Z,`0``!0U.,0$```!`?Q#1#C
M$!`,`!3`]/___>4```,`P!```%#(XQ`0```$!_$-$.,0$`P`%,#T___]U0``
M`QC`$```4+SC$!````0'\0T0XQ`0#``4P/3___W%```#,,`0``!0L.,0$```
M!`?Q#1#C$!`,`!3`]/___;4```-(P!```%"DXQ`0```$!_$-$.,0$`P`%,#T
M___]I0```V#`$```4)CC$!````0'\0T0XQ`0#``4P/3___V5```#>,`0``!0
MC.,0$```!`?Q#1#C$!`,`!3`]/___84```.0P!```%"`XQ`0```$!_$-$.,0
M$`P`%,#T___]=0```ZC`$```4'3C$!````0'\0T0XQ`0#``4P/3___UE```#
MP,`0``!0:.,0$```!`?Q#1#C$!`,`!3`]/___54```/8P!```%!<XQ`0```$
M!_$-$.,0$`P`%,#T___]10```_#`$```4%#C$!````0'\0T0XQ`0#``4P/3_
M__TU```$",`0``!01.,0$```!`?Q#1#C$!`,`!3`]/___24```0@P!```%`X
MXQ`0```$!_$-$.,0$`P`%,#T___]%0``!#C`$```4"SC$!````0'\0T0XQ`0
M#``4P/3___T%```$4,`0``!0(.,0$```!`?Q#1#C$!`,`!3`]/___/4```1H
MP!```%`4XQ`0```$!_$-$.,0$`P`%,#T___\Y0``!(#`$```4`CC$!````0'
M\0T0XQ`0#``4P/3___S5```$F,`0``!/_.,0$```!`?Q#1#C$!`,`!3`]/__
M_,4```2PP!```$_PXQ`0```$!_$-$.,0$`P`%,#T___\M0``!,C`$```3^3C
M$!````0'\0T0XQ`0#``4P/3___RE```$X,`0``!/V.,0$```!`?Q#1#C$!`,
M`!3`]/___)4```3XP!```$_,XQ`0```$!_$-$.,0$`P`%,#T___\A0``!1#`
M$```3\#C$!````0'\0T0XQ`0#``4P/3___QU```%*,`0``!/M.,0$```!`?Q
M#1#C$!`,`!3`]/___&4```5`P!```$^HXQ`0```$!_$-$.,0$`P`%,#T___\
M50``!5C`$```3YSC$!````0'\0T0XQ`0#``4P/3___Q%```%<,`0``!/D.,0
M$```!`?Q#1#C$!`,`!3`]/___#4```6(ZV_P,``DP-```!S-X_#_2/]QXS#P
MJ``DXT#PH``D4"#PM$%`\*!!,/"H02#PM,#E___^:<1(``!/JL0H``!/H[D$
M`#3`Y?___.[$&```3V>5`!``IW0`'L#E___]Q,0K``!8!>PF``@`?*<I``'`
MY?___GG`Y?___M;$&```3V?C(!```!;`Y?___TV2`"DAQ+@``$]<XR"P```6
MP.7___]"E@(D^N,@L```%L#E____.E@0\+26`23Z["$`!0#8XQ#0```$N10`
M(NPA``S`9<0X``!/0,`@```=1L#E___\4NLB``,`#<#E___^?.,P\*@`!.,0
M,```!.,0(```),`0```=R>,0(`@`),08``!/>N,0(!``),`0```=O^,0(!@`
M)%A`\+3`$```5Y@21.5,$```!*<8``&Y\B`4Q"L``%>)03`P"*<(``&G%@!L
M[!0`!`#8N10`$>L1``,`#>,1+_C_<;D$`%+E2!````"G2@`#IVD``+D4`$3`
M,```$+K$*```5W/`Y?___,P8LNPF``H`?L0H``!7:<#E___^`ABRQ"@``%=B
MP.7___UKP"```!Q3P.4```W!["8`(@!\P!```%=/XQ`0```"IW0`"\`@```<
M&L#E```-L,0K``!70<`0``!7/N,0$````J>$``C$*```5S;`Y0``&S_$*```
M5S3`Y?___KW`Y?__^UJY%``KXT#Q*``$ZV_PZ``$!_3L4``$`-CCL#````2Y
M%`!5IPH``>M5``,`#:<[``CCM2_X_R2G]/^"!P<'![D$`"_`,````!+C,#``
M`!BG^_]@IPD``.,`\```),#T````"0<'!P<``)CX!P<'!^MO\#``).,P(`0`
M%./P_UC_<4%`(`CE2/"@``#`8```&U+`4/__^LO`(/___JS`Y?___/D'!P<'
MP!```$ZHP"```$ZE01`0![D)`!+L'``*#GW$&```3C/L&``$`'P'\0?^!P<'
M!P<'P#```$Z0P!```$Z-N>D0$^L1``,`"NLQ`#\`#+D(`#'K,P`!``KL.``-
M`'S$&```3B[L&``'`'S`(```3G0'\0?^!P<'!P<'P!```$YLE0`0``=^ZZ_P
M4``DP!```$X/X_#_8/]QXQ`0```"IX0`",0H``!.',#E___\X<"P``!+^L"@
M``!+^[D)`*OKJ@`#``JGJ___Q!@``$Y)[*$`("!EP.7___^7P!```$W,XQ`0
M```"IX0`",`@```Z^,#E___Z_<`0``!.+N-`\1``!)(!$`#KK_#P``0']*<;
M``'$&P``3B3K$0`#``WC$;````0-X:?T_]'K[_!P`"3C\/]@_W'C0/$0``3K
M[_$0``0']`<'!P<'!^OO\'``),`0``!-L>/P_V#_<>,0$````J>$``O`,```
M3?[`(```.K?`Y?___(S`(```2YWC$"````*GA``)Q!@``$UY[!@`!`!\#>'K
M[_$0``3`]/___TOK[_!P`"3C\/]@_W'C0/$0``3K[_$0``0']`<'!P<'![)/
M`!#K$0`@``VR3P`1ZV_P,``DIUD`"./P_-#_<=('\R@0*$&@(#A!$/"HI[D`
M`+D$`#'C2Z````3K!``@``SC`#```"3`2@````#C0#`(`"2GNP`(ISL`$*=7
M_^U!0/*HXS`0:``$XS`00`""XS`0$`""XS`0``""[%,@OV%5[%,@/@%6XU`0
M@``DIQL`".Q!_^E@9.,0\*@`!,(:6H)YF>,0("``".,P(```!..`(!``!.,`
M(`@`!.-0(!@`!.RC(+]E5>QP(+]^5>RC(#H%5NQP("$>5KD(`*&YYW"XN>=0
M&+F``+.Y@``0N8(`N+F"`!7LTR"_?E6Y"`"A[-,@(1Y6[$H@OP!5XQ#PL``$
MN8``K<(:6H)YF>MD``(`#+D(`!7L9"`A'E:Y"``;Z[0`&P`,[+0@.@56N0@`
ML>R;(+\`5;F``+:G&?__N><0%*=)__^Y@``7N>=`2;F!`!JY@`!-XZ#PN``$
MN8$`2\*J6H)YF>.P\,``!+D(`*C"NEJ">9FY"`"AN0@`>[D(`'3K&0`;``SL
M&2`Z!5:Y"``:[*$@OP!5ZTH`&P`,[$H@.@56N0@`1^MY``(`#.QY("$>5KF`
M`!>GF?__N>>0FKF``):Y@0"1XQ#PR``$PAI:@GF9N0@`T;D(`-GLM""_`%7K
MFP`;``SLFR`Z!5:Y"`"=Z]H``@`,[-H@(1Y6N8``3:>I__^YYZ"KN8``I[F!
M`*3C0/#0``3"2EJ">9FY"`!DN0@`:NP9(+\`5>NA`!L`#.RA(#H%5KD(`*;K
M:P`"``SL:R`A'E:Y@`"6I[G__[GGL+&Y@`"]N8$`N>.0\-@`!,*:6H)YF>Q*
M(+\`5;D(`'GKD0`"``SLD2`A'E:Y@`"IN0@`>Z<9__^YYQ`4N8``%KF!`!KC
MH/#@``3"JEJ">9FY"`#:N0@`T>NT`!L`#.RT(#H%5KD(`+?L>R"_`%7K%P`;
M``SL%R`Z!5:Y"``=Z]0``@`,[-0@(1Y6N8``O:=)__^YYT!'N8``2;F!`$OC
ML/#H``3"NEJ">9FY"`!KN0@`9.RA(+\`5>M*`!L`#.Q*(#H%5KD(`$;K9P`"
M``SL9R`A'E:Y@``6IWG__[GG<'JY@`!]N8$`<>,0\/``!,(:6H)YF;D(`)&Y
M"`"7[+0@OP!5ZWL`&P`,['L@.@56N0@`>>N:``(`#.R:("$>5KF``$FGJ?__
MN>>@J[F``*:Y@0"DXT#P^``$PDI:@GF9N0@`U+D(`-KL%R"_`%7KH0`;``SL
MH2`Z!5:Y"`"MZ]L``@`,[-L@(1Y6N8``?:>Y__^YY["QN8``N;F!`+?C</$`
M``3">EJ">9GL2B"_`%6Y"`!GZW$``@`,['$@(1Y6N8``I[D(`&NG&?__N><0
M%+F``!VY@0`:XZ#Q"``$PJI:@GF9N0@`FKD(`)'KM``;``SLM"`Z!5:Y"`"V
M[&L@OP!5ZQ8`&P`,[!8@.@56N0@`&>N4``(`#.R4("$>5KF``+FG2?__N>=`
M1KF``$>Y@0!+X[#Q$``$PKI:@GF9N0@`V[D(`-3LH2"_`%7K2@`;``SL2B`Z
M!5:Y"`!-Z]8``@`,[-8@(1Y6N8``':=I__^YYV!JN8``:;F!`&'C$/$8``3"
M&EJ">9FY"`!QN0@`=NRT(+\`5>MK`!L`#.QK(#H%5KD(`&?K>@`"``SL>B`A
M'E:Y@`!'IZG__[GGH*NY@`"MN8$`I.-`\2``!,)*6H)YF;D(`)2Y"`":[!8@
MOP!5ZZ$`&P`,[*$@.@56N0@`J>N;``(`#.R;("$>5KF``&FGN?__N>>PL;F`
M`+>Y@0"VXV#Q*``$PFI:@GF9N0@`UKD(`-OL2B"_`%7KM``;``SLM"`Z!5:Y
M"`"]Z]$``@`,[-$@(1Y6N8``K:<9__^YYQ`4N8``&;F!`!KCH/$P``3"JEJ"
M>9FY"`!ZN0@`<>QK(+\`5>L6`!L`#.P6(#H%5KD(`!?K=``"``SL="`A'E:G
M2?__N8``M[GG0$:Y@`!-N8$`2^RA(+\`5>.P\3@`!,*Z6H)YF;D(`)NY"`"4
MZTH`&P`,[$H@.@56N0@`2>-`\*``).R4(+\`5>NV`!X`#:=)___K9@`"``RY
MYT!*N8``1[F!`+;L:R"_`%6Y@``6N8$`%.-`\4``!,)*6H)YF;D(`-3K2@`>
M``WKJ@`"``RY@0"DN8(`NN-`\*``!+F"`$OCL/%(``3"NF[9ZZ&Y"`![Z[D`
M'@`-N0@`T>L9`!L`#.P9(#H%5NN9``(`#+D(`!VY@0";N>>0NKF"`+'LT2"_
M`%6Y&@!TXQ#Q4``$N00`1\(:;MGKH;D(`!:Y&@`;Z[T`'@`-ZWT`&P`,['T@
M.@56Z]T``@`,N0@`=+F!`-OL1R"_`%7CL/%8``3"NF[9ZZ&Y&@"ZN>?0J;F"
M`'JY&@"WZW0`'@`-ZV0`&P`,[&0@.@56ZT0``@`,N8$`1^-P\6``!,)Z;MGK
MH;D:`'FY"`!AN00`J^P6(+\`5;D$`)>YYT!]N8(`9[D:`);KL0`;``RY!`!Y
M[+$@.@56N0@`NNRK(+\`5>N:`!L`#.R:(#H%5NMA`!X`#;D(`)?L>2"_`%7K
M$0`"``RY@0`6XV#Q:``$PFINV>NAN1H`;;GG$-2Y@@"]Z]H`'@`-ZZH``@`,
MN8$`K>/0\7``!,+:;MGKH;D:`-2Y!`!-N>>@T;F"`)WKUP`>``VY&@!KZ[<`
M&P`,[+<@.@56ZW<``@`,N8$`?>/0\7@`!,+:;MGKH;D:`-&Y!``=N>=PVKD(
M`+:Y&@!)[&L@OP!5N8(`O>O6`!X`#;D$`)3K1@`;``SL1B`Z!5;K9@`"``RY
M@0!MX]#Q@``$PMINV>NAN1H`VKD$`*VYYV#7N0@`2;D:`!OLE""_`%6Y@@!-
MZ]D`'@`-N00`L>L9`!L`#.P9(#H%5NN9``(`#+F!`)WCT/&(``3"VF[9ZZ&Y
M&@#7N00`?;GGD-:Y"``;[+$@OP!5N8(`'>O;`!X`#;D:`*3K2P`;``SL2R`Z
M!5;KNP`"``RY@0"]X]#QD``$PMINV>NAN1H`UKD$`&VYY[#9N0@`2NRD(+\`
M5;F"`$WKV@`>``VY&@!QZQH`&P`,[!H@.@56ZZH``@`,N8$`K>/0\9@`!,+:
M;MGKH;D:`-FY!`"=N>>@V[D(`!?L<2"_`%6Y@@`=Z]<`'@`-N1H`9.M'`!L`
M#.Q'(#H%5NMW``(`#+F!`'WCT/&@``3"VF[9ZZ&Y&@#;N00`O;GG<-JY"`!&
M[&0@OP!5N8(`3>O6`!X`#;D:`)'K%@`;``SL%B`Z!5;K9@`"``RY@0!MX]#Q
MJ``$PMINV>NAN1H`VKD$`*VYYV#7N0@`&>R1(+\`5;F"`!WKV0`>``VY&@"T
MZTD`&P`,[$D@.@56ZYD``@`,N8$`G>/0\;``!,+:;MGKH;D:`->Y!`!]N>>0
MUKD(`$OLM""_`%6Y@@!-Z]L`'@`-N1H`H>L;`!L`#.P;(#H%5NN[``(`#+F!
M`+WCT/&X``3"VF[9ZZ&Y&@#6N00`;;GGL-FY"``:[*$@OP!5N8(`'>O:`!X`
M#;D:`'3K2@`;``SL2B`Z!5;KJ@`"``RY@0"MX]#QP``$PMINV>NAN1H`V;D$
M`)VYYZ#;N0@`1^QT(+\`5;F"`$WKUP`>``VY&@!AZQ<`&P`,[!<@.@56ZW<`
M`@`,N8$`?>/0\<@`!,+:;MGKH;D:`-NY!`"]N>=PVKD(`!;L82"_`%6Y@@`=
MZ]8`'@`-N1H`E.M&`!L`#.Q&(#H%5NMF``(`#+F!`&WCT/'0``3"VF[9ZZ&Y
M&@#:N00`K;GG8->Y"`!)[)0@OP!5N8(`3>O9`!X`#;D:`+'K&0`;``SL&2`Z
M!5;KF0`"``RY@0"=X]#QV``$PMINV>NAN1H`U[D$`'VYYY#6N0@`&^RQ(+\`
M5;F"`!WKVP`>``VY&@"DZTL`&P`,[$L@.@56Z[L``@`,N8$`O>/0\>``!,+:
M;MGKH;D:`-:Y!`!MN>>PV;D:`'&Y"`!*[*0@OP!5N8(`3>L:`!L`#.O:`!X`
M#>P:(#H%5KD(`!?KJ@`"``SL<2"_`%6Y@0"MN>:@V[F``-&YY*`;N8$`T;D:
M`&3C$/'H``3K1P`;``S"&H\;O-SL1R`Z!5:Y&@`9N0@`1KD:`!WKUP`>``WL
M9""_`%7K=P`"``RY@0!]N>9PVKF``-2YY'!*N8$`U+D$`)'C0/'P``3K%@`;
M``S"2H\;O-SL%B`Z!5:Y&@!+N0@`&;D:`$WKU@`>``WLD2"_`%7K9@`"``RY
M@0!MN>9@U[F``-&YY&`7N8$`T;D$`+3C$/'X``3K20`;``S"&H\;O-SL22`Z
M!5:Y&@`:N0@`2[D:`!WKV0`>``WLM""_`%7KF0`"``RY@0"=N>:0UKF``-2Y
MY)!&N8$`U+D$`*'C0/(```3K&P`;``S"2H\;O-SL&R`Z!5:Y&@!'N0@`&KD:
M`$WKVP`>``WLH2"_`%7KNP`"``RY@0"]N>:PV;F``-&YY+`9N8$`T;D$`'3C
M$/((``3K2@`;``S"&H\;O-SL2B`Z!5:Y&@`6N0@`1[D:`!WKV@`>``WL=""_
M`%7KJ@`"``RY@0"MN>:@V[F``-2YY*!+N8$`U+D$`&'C0/(0``3K%P`;``S"
M2H\;O-SL%R`Z!5:Y&@!)N0@`%KD:`$WKUP`>``WL82"_`%7K=P`"``RY@0!]
MN>9PVKF``-&YY'`:N8$`T;D$`)3C$/(8``3K1@`;``S"&H\;O-SL1B`Z!5:Y
M&@`;N0@`2;D:`!WKU@`>``WLE""_`%7K9@`"``RY@0!MN>9@U[F``-2YY&!'
MN8$`U+D$`+'C0/(@``3K&0`;``S"2H\;O-SL&2`Z!5:Y&@!*N0@`&[D:`$WK
MV0`>``WLL2"_`%7KF0`"``RY@0"=N>:0UKF``-&YY)`6N8$`T;D$`*3C$/(H
M``3K2P`;``S"&H\;O-SL2R`Z!5:Y&@`7N0@`2KD:`!WKVP`>``WLI""_`%7K
MNP`"``RY@0"]N>:PV;F``-2YY+!)N00`<;F!`-3C0/(P``3"2H\;O-RY&@!&
MN1H`3;D$`&3KV@`>``WK&@`;``SL&B`Z!5:Y"``7['$@OP!5ZT<`&P`,[$<@
M.@56N0@`1NQD(+\`5>NJ``(`#+F!`*VYYJ#;N8``T;GDH!NY@0#1XQ#R.``$
MPAJ/&[S<N1H`&;D:`!WKUP`>``WK=P`"``RY@0!]N>9PVKF``-2YY'!*N8$`
MU+D$`)'C0/)```3K%@`;``S"2H\;O-SL%B`Z!5:Y&@!+N0@`&;D:`$WKU@`>
M``WLD2"_`%7K9@`"``RY@0!MN>9@U[F``-&YY&`7N8$`T;D$`+3C$/)(``3K
M20`;``S"&H\;O-SL22`Z!5:Y&@`:N0@`2[D:`!WKV0`>``WLM""_`%7KF0`"
M``RY@0"=N>:0UKF``-2YY)!&N8$`U+D$`*'C0/)0``3K&P`;``S"2H\;O-SL
M&R`Z!5:Y&@!'N0@`&KD:`$WKVP`>``WLH2"_`%7KNP`"``RY@0"]N>:PV;F`
M`-&YY+`9N8$`T;D$`'3C$/)8``3K2@`;``S"&H\;O-SL2B`Z!5:Y&@`6N0@`
M1[D:`!WKV@`>``WL=""_`%7KJ@`"``RY@0"MN>:@V[F``-2YY*!+N8$`U+D$
M`&'C0/)@``3K%P`;``S"2H\;O-SL%R`Z!5:Y&@!)N0@`%KD:`$WKUP`>``WL
M82"_`%7K=P`"``RY@0!]N>9PVKF``-&YY'`:N8$`T;D$`)3C$/)H``3K1@`;
M``S"&H\;O-SL1B`Z!5:Y&@`;N0@`2;D:`!WKU@`>``WLE""_`%7K9@`"``RY
M@0!MN>9@U[F``-2YY&!'N8$`U+D$`+'C0/)P``3K&0`;``S"2H\;O-SL&2`Z
M!5:Y&@!*N0@`&[D:`$WKV0`>``WLL2"_`%7KF0`"``RY@0"=N>:0UKF``-&Y
MY)`6N8$`T;D$`*3C$/)X``3K2P`;``S"&H\;O-SL2R`Z!5:Y&@`7N0@`2KD:
M`!WKVP`>``WLI""_`%7KNP`"``RY@0"]N>:PV;F``-2YY+!)N8$`U.-`\H``
M!,)*CQN\W+D:`$:Y&@!-Z]H`'@`-N00`<>L:`!L`#.P:(#H%5NNJ``(`#+F!
M`*WCT/*(``3"VLIBP=:Y&@#9N00`G;GGH-NY"``7['$@OP!5N8(`'>O7`!X`
M#;D$`&3K1P`;``SL1R`Z!5;K=P`"``RY@0!]X]#RD``$PMK*8L'6N1H`V[D$
M`+VYYW#:N0@`1NQD(+\`5;F"`$WKU@`>``VY&@"1ZQ8`&P`,[!8@.@56ZV8`
M`@`,N8$`;>/0\I@`!,+:RF+!UKD:`-JY!`"MN>=@U[D(`!GLD2"_`%6Y@@`=
MZ]D`'@`-N1H`M.M)`!L`#.Q)(#H%5NN9``(`#+F!`)WCT/*@``3"VLIBP=:Y
M&@#7N00`?;GGD-:Y"`!+[+0@OP!5N8(`3>O;`!X`#;D:`*'K&P`;``SL&R`Z
M!5;KNP`"``RY@0"]X]#RJ``$PMK*8L'6N1H`UKD$`&VYY[#9N0@`&NRA(+\`
M5;F"`!WKV@`>``VY&@!TZTH`&P`,[$H@.@56ZZH``@`,N8$`K>/0\K``!,+:
MRF+!UKD:`-FY!`"=N>>@V[D(`$?L=""_`%6Y@@!-Z]<`'@`-N1H`8>L7`!L`
M#.P7(#H%5NMW``(`#+F!`'WCT/*X``3"VLIBP=:Y&@#;N00`O;GG<-JY"``6
M[&$@OP!5N8(`'>O6`!X`#;D:`)3K1@`;``SL1B`Z!5;K9@`"``RY@0!MX]#R
MP``$PMK*8L'6N1H`VKD$`*VYYV#7N0@`2>R4(+\`5;F"`$WKV0`>``VY&@"Q
MZQD`&P`,[!D@.@56ZYD``@`,N8$`G>/0\L@`!,+:RF+!UKD:`->Y!`!]N>>0
MUKD(`!OLL2"_`%6Y@@`=Z]L`'@`-N1H`I.M+`!L`#.Q+(#H%5NN[``(`#+F!
M`+WCT/+0``3"VLIBP=:Y&@#6N00`;;GGL-FY"`!*[*0@OP!5N8(`3>O:`!X`
M#;D:`''K&@`;``SL&B`Z!5;KJ@`"``RY@0"MX]#RV``$PMK*8L'6N1H`V;D$
M`)VYYZ#;N0@`%^QQ(+\`5;F"`!WKUP`>``VY&@!DZT<`&P`,[$<@.@56ZW<`
M`@`,N8$`?>/0\N``!,+:RF+!UKD:`-NY!`"]N>=PVKD(`$;L9""_`%6Y@@!-
MZ]8`'@`-N1H`D>L6`!L`#.P6(#H%5NMF``(`#+F!`&WCT/+H``3"VLIBP=:Y
M&@#:N00`K;GG8->Y"``9[)$@OP!5N8(`'>O9`!X`#;D:`+3K20`;``SL22`Z
M!5;KF0`"``RY@0"=X]#R\``$PMK*8L'6N1H`U[D$`'VYYY#6N0@`2^RT(+\`
M5;F"`$WKVP`>``VY&@"AZQL`&P`,[!L@.@56Z[L``@`,N8$`O>/0\O@`!,+:
MRF+!UKD:`-:Y!`!MN>>PV;D(`!KLH2"_`%6Y@@`=Z]H`'@`-N1H`=.M*`!L`
M#.Q*(#H%5NNJ``(`#+F!`*WCT/,```3"VLIBP=:Y&@#9N00`G;GGH-NY&@!A
MN0@`1^QT(+\`5;F"`$WKUP`>``VY&@"4ZQ<`&P`,[!<@.@56ZW<``@`,N0@`
M%KF!`'WL82"_`%7CT/,(``3K1@`;``S"VLIBP=;L1B`Z!5:Y&@#;N0@`2>R4
M(+\`5;D$`+VYYW#:N8(`'>O6`!X`#>MF``(`#+F!`&WCT/,0``3"VLIBP=:Y
M&@#:N00`K;GG8->Y@@!-Z]D`'@`-N1H`L>L9`!L`#.P9(#H%5NN9``(`#+F!
M`)WCT/,8``3"VLIBP=:Y&@#7N00`?;GGD-:Y&@"DN0@`&^RQ(+\`5;F"`!WC
MT/,@``2Y&@!QPMK*8L'6N1H`UNM+`!L`#+D$`&WL2R`Z!5:Y"`!*[*0@OP!5
MZQH`&P`,[!H@.@56N0@`%^M[`!X`#<`:`````.N[``(`#+F!`+>YY[#9N8(`
M3;D(``&Y&@!DP`H`````XP`@"``DZT$`&P`,N1H`6^Q!(#H%5L!:`````.-0
M(!@`)+D(`$;C$"`@``2Y&@`TN1H`&<`Z`````.,P(```),`:`````.,0("``
M).MZ``(`#.QZ("$>5KD(`(?`B@````#C@"`0`"2R3P`0ZQ$`(``-LD\`$=4'
M\R@0**>$``7`Y?__\:OC0/.@``3K;_-@``0']`<'ZV_P,``DX_#_8/]Q["@`
M40!\Q!@``$%CXV`0```"IX0`2+D$`$+C$$```)3L%@`V`'X;0KD$`(*Y!`!S
MN00`IKD4`+3CD*````*GA``>N00`2[D$`#CC(*````3`Y?__[Q+L)@`B`'Y!
M&Y``E3T0`*=T`!NY"0"F09N0`>NJ``,`"E"@<`"Y!``IXT#Q$``$ZV_PT``$
M!_3L&/_-/7Y!0$`!I_3_PD&@H`BG]/_-IYD``*?T_^H'!^OO\'``)+)/`!#K
M$0`@``VR3P`1X_#_4/]Q03#PI-('\*@0*,#E____DK)/`!#K$0`@``VR3P`1
MU0?PJ!`HIX0`!<#E___Q(^-`\2``!.OO\2``!`?T!P?KK_!0`"2R3P`0X_#_
M4/]QZQ$`(``-LD\`$;D$`++2!_"H$"A!H/"DN00`.KD$`"O`Y?___V#L)@`2
M`'RR3P`0ZQ$`(``-LD\`$=4'\*@0**>$`![`Y?__\.[C$/"D`!3$*```0+3K
M$0`#``WC$"````CC(!`(``3C(!```"3L*/_5`'Q!$!`(I_3_]>-`\2``!.NO
M\0``!`?T!P<'!P<'ZV_P,``DP-````V9X_#_4/]QLD\`$.L1`"``#;)/`!&Y
M!`"SIP@``-('\*@0*.,0,```E*<X``#`%P```#VY^Q`3X[#0``"(IZD``+D$
M`)*Y!``;03#PI+)>`*&G%/_^N0D`J\#E___^]NPH`#$`?*<(``"G&0``N00`
M,K)>`!.G%/_^N0D`$NRA`)$@9:<9``#C,;```)!",2``IQL``>PV__D`?*<H
M``"R3P`0ZQ$`(``-LD\`$=4'\*@0*+D4`"*GA`#.P.7___!EQ!@``$`NXW`0
M```$IQD``!B!IQL``>LA``,`#>,B?_C_`J=T__?`$```2)/C$!```!*GA``<
M[#@``@#8N00`)[D4`#/K,P`#``W`Y?__[,W$&```0`;C(!```"3L)@`M`'RG
M*/__I_3_O,`0``!(<>PH``(`V.5,$````;D4`"+K(@`#``W`Y?__[9^Y!`!B
M["C_Z0!\N10`2+D$`#?K1``#``W`Y?__[:#$&```/]GC8!```"2Y%``8Q"@`
M`#_1IQL``>,@(```!.L1``,`#4$1(`#E2!````!0@/"DN00`&>,@$```E.PF
M`$<`?KD)`!GL*@`"`-FY&``AQ(@``#^PXW#PI``4ZW<``P`-XW"````(P.7_
M_^U8XR!P```D["C_H0!\XQ#PI``4XR"````$ZQ$``P`-XQ$@```$XR"0``"0
M0B`0`$&0D`&YE``B["8`&@!^DCT0`*<I``#C,K```)!",A`!IRL``>PV__D`
M?*?T_S3L*/^\/7Y!$!`!I_3_L>PH_^D]?D$0$`&G]/_8XU#Q(``$ZV_PX``$
M!_4'!P<'ZW_P.``DLD\`$./P_LC_<>L1`"``#;)/`!'2!_$P$"CL*``E`'RY
M!`"BE0`@`*>$`![`Y?__Z]>Y!`""["@`%P!\07#PH+D$`"C`Y?__[(OL)@`<
M`'RY!``HP.7__^TSN00`*L#E___NGK)/`!#K$0`@``VR3P`1U0?Q,!`HIX0`
M;L#E___O3T&P(!/`$```#$:G"```N00`*[)=`!*G%/_^IX3_TL`0```,.KD$
M`"NR70`2IQ3__J>$_\>Y!``:IRD``+)>`"&G%/_^N00`.Z<9``"R7@`3IQ3_
M_KD)`!NY"0`J&B&G*@`"N10`(L#E___LF<`P```,%;D$`)*Y!`!;N00`2L#E
M___NS;D$`#>Y!``IP.7__^Z&["@`&?]^6!#PN*<H0`#`&P``\`#L$@`/8':Y
M!``IP.7___]DN00`*<#E___N7Z?T_W^Y!``IP.7__^Q8I_3_].-`\:@`!.M_
M\7``!`?TLD\`$.L1`"``#;)/`!'KO_!8`"3C\/[(_W&Y!`"RT@?Q,!`H03#P
MH,#E___LB.PF`#``?A@2ISA``%@@\+C`*P``\`#L(P`(@':E/Z``[",`#V!V
MISD``KD$`"O`Y?__ZUX0$J<:__^($``?N10`(;)/`!#K$0`@``VR3P`1U0?Q
M,!`HIX0`"<#E___NF*<8``"G]/_MXT#QJ``$Z[_QD``$!_0'!P<'Z^_P<``D
MQ!@``#Y)X_#_8/]QXR`0```6P.7__^XLP%````MMQ$@``#Y2P#````MUZ^_Q
M$``$P/3__^W]!P<'!^MO\#``)./P_UC_<<2X```^)N,@L```%L!@```,Q,#E
M___N"<#E____SN,@L```%L#E___N`+D$`%;E2/"@``#`0```",3`,```"U7`
MY?__ZQ+C0/$8``3K;_#8``0'].MO\#``)+)/`!#C\/]0_7'K$0`@``WC(/"H
M`G&R3P`1T@<@`!`HP.7__^LU0;#PIKD$`%+`8```"SG`0```"SBG.1`!N00`
M*\#E___JU.PF`!G_?J>Y``"R3P`0XS#PJ`)QZQ$`(``-LD\`$;D$`"O5!S``
M$"BGA`!*P.7__^W[["`0`"!Q["3_YP!^XZ#PIP%QITD0`+D$`#JY!``KP.7_
M_^QIN00`@NPD_]8`?J<J``&Y%``BP.7__^M=N00`LNPH_\H`?+D4`)CL*@`'
MH&5!&2``N6%`H>RZ``?`94$9H`"Y84"Q[(`0`2!RN00`2;D$`#JY!``KP.7_
M_^V,01FP`)(`$`"G]/^IXT#Q(`($ZV_PX`($!_3`]/___W0'!^MO\#``)+)/
M`!#C\/[`_G&Y!`"RZQ$`(``-XR#Q.`%QLD\`$;D$`(/2!R``$"C`(```"K3`
MY?___$JG.0`ON00`DKD$`"O`Y?__Z[7L*``?`'RY!``[P"````JEP.7___RR
MLD\`$.,P\3@!<>L1`"``#;)/`!&Y!``KU0<P`!`HIX0`K\#E___M9J<(``"Y
M!``;N00`**>I``#`,```"HJR7@"AIQ3__D&`\3@;JT%P\*BGJ@`!P.7__^SM
M["C_RP!\E0`@`,`0```*0;GB@"'LF``9`'RG"```N00`$KD$`#FR70`3IQ3_
M_J=T``S`,```"F"G*0``P.7__^S,I_3_WZ<(``"G&0``N00`,K)>`!.G%/_^
M&Q*Y%``QXS,O__]QE2\P`*>$`",:&J<X#__L$_^1(';CL/"@`"2Y!`!2P&``
M``HXP$````JHISD0`+D$`"C`Y?__Z;ZG&!``IRH``>PA``_`=Z?T``&G&O__
MN10`,4$S(`"2`#``I_3_SKD$`#>Y!``HP.7__^QD[";_L`!^6!#PP*4O@`#`
M&P``\`#L$O^F8':G.0`!N00`*,#E___I@.PF_YP`?KD$`#C`(```"?#`Y?__
M^_VY!``HP.7__^J@N00`LJ?T_T3C0/&P`03K;_%P`00']`<'!P=!$"`!XS`?
M__^4[#8`!`!^!_ZG/@`ON>*`(:<;``&G]/_S!P<'!P<'["@`"0!\XU`@``"4
M[%8`"0!^P"````F/P/3__^IPN00`,J<(``"G&0``LEX`$Z<4__[C0!___W&Y
MZ2`Q["0`!B!E["8`!?]\ISD``:<W`!+L)``L8&3L6/_>+W[`(```"9ZG]/_;
MXT!/__]QI_3_\)4O0`"GA/_YN>D@%.,P3___<;DA`".G.0`!N>(P$Z?T``GC
M0$___W&G%P`$I_3_VI4O0`"G=/_WN>D@%.,P3___<>PC``8@9>PF``7_?*<9
M``'C0$___W&G%P`/N0D`0J<Y$`#L%``"`-GL$P`,P&6G*0``!_Z5+T``IX3_
M[*?T_^_K[_!P`"2G2P`!X_#_8/]QN00`,NQ`$``@<<`@```\6L#E___JH\`@
M```\5.-`\1``!.OO\1``!`?T!P<'!^OO\'``)+)/`!#K$0`@``VR3P`1X_#_
M,/]QP"````DHT@?PR!`HP!````C)TB'PIA``P.7___K3P"````D>P.7___K-
MP"````D<P.7___K'P"````D;P.7___K!P"````D9P.7___J[P"````D;P.7_
M__JUP"````CMP.7___JOP"````D5P.7___JIP"````D4P.7___JCP"````D3
MP.7___J=P"````C:P.7___J7P"````D,P.7___IE["@`"P!\N00`,L`@```(
M]\#E___ZUL`@```)!,#E___Z5.PH``L`?+D$`#+`(```"0+`Y?__^L7`(```
M"0+`Y?__^D/L*``C`'RY!``RP"````BBP.7___JTP#````D(P"````BYP.7_
M__JKLD\`$.L1`"``#;)/`!'5!_#($"BGA``FP.7__^MDP"````CAP.7___H:
M["@`"@!\N00`,L`@```(IZ?T_]>G20`*P#````C802#PM\#E___HZNPF_\X`
M?D$P\,&G]/_LXT#Q0``$Z^_Q0``$!_0'!\0=```[5*<>__^G=``PZ^_P<``D
MP"````A_X_#_8/]QP.7___GD["@`'@!\XQ`@``"0[!@`&`!\P!<````PN0,`
M$>L1`#\`#,0?```[,.-`\1``!,0L```[*NOO\1``!`?TIQ@``*?T__'$+```
M.Q\'_@<'!P<'!^OO\'``)./P_V#_<<#E___K!L#E___I0^PH``T`?.,@(```
M!.-`\1``!.OO\1``!`?TIRD``*?T__<'!P<'!P?K;_`P`"2Y!`"RX_#_8/]Q
MP"````ADP.7___F-N00`.^PH``D`?+D$`&*5`"``IW0`"\`@```(4^MO\-``
M!,#T___Y]<#E___HNNPF`"T`?*<(``"Y!``;LEX`(:<4__ZY!``VIQD``+)>
M`!.G%/_^N0D`%KD)`"M!(A`"P.7__^@>P#````@^N00`HL!0```'Q;D$`$O`
MY?__ZE&Y!``ZI_3_R>-`\1``!.MO\-``!`?T!P<'!P<'ZV_P,``DP-````=I
MN00`[^/P_?#W<:?K_^!@@.``8*#@"&#`X!!@X.`8LD\`$.L1`"``#;)/`!&Y
M!`"BXR#QZ`AQT@<@`!`HP!```#I(TA?PN!``P!```#I.TB_PZ!``P!```#I@
MTA?PT!``P"````=MP.7___D#["@`)P!\N00`LI4`(`"GA``@P.7___]?N00`
M*\#E___H%KD$`(*R3P`0XS#QZ`AQZQ$`(``-LD\`$;D$`"C5!S``$"BGA`2*
MP.7__^H@P.7___\A["8`VP!\09#PT.,0D````J=T``?`L```!ZBG]``9XR"0
M```$P.7___C$["@`P@!\E0`@`*>$`+W`Y?__Y]ZY!`"RIYL`".RX_^(`?*<(
M``"Y!``;IRD``+)>`"&G%/_^N0D`*^LB``$`#:<K``'`Y?__YV.Y!`"2N00`
M@N-`L```E.Q&`)X`?D&P\.CC@+````*GA``>XR"P```$P.7___B(N00`@NPH
M`)P`?)4`(`"GA`"7P.7___KD["@`D@!^N00`*,#E___GF+D$`()!L/"X[(8`
M#`!\XW"P```"IX0`!I4`<`"G=`"`IP@``+D$`!BGN0``LEX`L:<4__ZY!``I
MIQD``+)>`!*G%/_^N0D`&;D)`+@:L:>Z!`2Y%`"[N00`*\!@```')\#E___G
M!>.0\*``)+D$`'+`,```!Q_`4```!JJY!`!(P.7__^DUISD!P+D$`"?`Y?__
MZ,[L)@!8_W[`Y?__Z+C5`]``(`"GA`!/X["@```$P.7__^BMQ!@``#D"XV`@
M```4N00`5[D$`$O`,```!O?C(!````3`Y?__Z"JGB0``I_3_%*>Y``"G]/](
MN00`LJ?T_TFY!``HN10`1,`P```&TT&PL`%!@(`"P.7__^CPI_3_4:>[``BG
M]/]5XR"P```$P.7___I(["@`"@!^N00`)\#E___F_+D$`(*GNP`(I_3_9$$0
M\1BY!``GL\$`@;D$`#'`Y?__YLL8DNPF`UP`?E@0\3"G*$``P!L``/``[!(#
M4F!V6(#Q-,#E___I".R"`TI@=E@0\3"G*`'`P!L```'_[!(#0&!VN00`*\#E
M___F9KD$`(+`(```!L3`Y?__]YKL*``5`'SCL*````3`Y?__YK6Y!``RN00`
M*\#E___[)KD$`++L)@`&`'SCL*````2G"```IQD``+D$`"NR7@`2IQ3__KD)
M`!OL'`!"`WZY%``AXS*__/]QP"````9TLET`(Z<4__ZG=``S[!@`#@1^IQK_
M_+D4`!'C$;___W&5+Q``IW0`)>,@H`@``J>$`""G"```IQD``+D$`#*R7@`3
MIQ3__KD)`!+L'``2`WWC(2_\_W'`$```!DFR70`2IQ3__J=T``7CL*`(``3`
MY?___3WL)@)S`'ZY!``KISD``,#E___F6[D$`+(8HNPH`F8`?J=)``*G.?_N
M06#QZ,#E___E7*=)``:Y!``VN00`*\#E___G<Y4`\>BG=`!/E4/QZ:=T`$N5
M0?'JIW0`1Y5#\>NG=`!#E4CQ[*=T`#^51?'MIW0`.Z=)``*G.?_&N00`*\#E
M___E,J=)`"FY!``VN00`*\#E___G2<`0```&CL!0```%4^,0\*``)+D$`$?`
M,```!>:Y!``HP.7__^?6N00`)\#E___G@;D$`#C`(```!2_`Y?__]T&Y!``H
MP.7___THI_3]T*=)``"G.0``N00`*\#E___D^<`19T4C`>,0\1@`),`?[\VK
MB>,0\2``),`?F+K<_N,0\2@`),`1$#)4=N,0\3``),`?P]+A\.,0\3@`)+D4
M`!KE2/%```"SP0"AY4CQ2```01#QD.5,\9```+/!`.&SS0`JI4^``+D$`#9!
MD/%0P.7__^;?XR#PL``D6*#PM.RB`.@`?K/-`"K`Y?__YK+CL/%```3CH/%(
M``3L&SJ_?57L00`!`-BY%``101'Q4)*`$`"Y%``D[$P!D#A^IQ@`0*<Y``"Y
M^4!!02*0`+D4`$3`Y?__Y-ZSS0`HP.7__^GEITD`.*<Y``"Y!``IIYD``,#E
M___DSD*@\8M"L/&/ZQH`&``,0A#QB.L:`!``#$(0\8GK&@`(``Q"$/&*L\T`
M*.L;`!@`#$(0\8SK&P`0``Q"$/&-ZQL`"``,0A#QCD&P\;^GJ0`4N00`:\#E
M___IK>,0\1@`!$(0\:[K(0`8``Q"(/&KZR$`$``,0B#QK.LA``@`#$(@\:WC
M$/$@``1"$/&RZR$`&``,0B#QK^LA`!``#$(@\;#K(0`(``Q"(/&QXQ#Q*``$
M0A#QMNLA`!@`#$(@\;/K(0`0``Q"(/&TZR$`"``,0B#QM>,0\3``!.LA`!@`
M#$(@\;="$/&ZZR$`$``,0B#QN.LA``@`#$(@\;GC$/$X``3K(0`8``Q"(/&[
MZR$`$``,0A#QOD(@\;SK(0`(``Q!$/&K0B#QO;/!`(&SS0`8N00`*\`P```$
M?N-)$```D*>[``*GFP`!P.7__^:8IZ?_[Y(`\>>G]/ZKXS#Q0``$XR#PM``4
MZQ(``P`-N0@`$\`:`````.PQ``;`9>L!\4@`>N,0\4``).LB`!T`#.,@\4@`
M".,@\4@`).,0\9``$J>$`'=8(/"TIZ@`0!NA&2JY\L"BN00`*;D8`"&Y%`"Z
M["8`"*!E01L@`.QA``M`9>PF``K`94$;8`#L(0`%H&6G]``!I1^``.RQ__P@
M9;D$`$NY!``VP.7__^91&!I:$/&04!#QD.P6_K)`?K/-`"A8$/"T&QI!NV``
M&*'`Y?__Z,KK&@`&`-[L(0`!`-@2JA@2IR@``;GRH"%0(/"P6!#PL*<:__]0
M$/"PIW0`)KD4`$KLN0`(P&5!%)``[+'_PD!E[+D`"*!E012P`.R1_[I`9>Q"
M_[=(?;D$`#NY!``IP.7__^8,4*#QD*?T_G"Y!`"VI_3_R.RY``C`9;/-`![L
ML?^@0&5!$+!`L\$`P>RY``:@9>R1_Y9`9;D$`#NG20!`N00`*;/-`+RGJO_`
MP.7__^7EL\T`*,#E___H;*?T_["G&``XISD``+GY0$%!(I``N10`1*?T_H'`
M,````X[`(````TW`L```!&'`Y?__]2[`Y?__XP/`$```!%BY!`!BXQ#PH``D
MP%````,8N00`1\`P```#MKD$`"C`Y?__Y9ZG.0'`N00`*,#E___E-^PF_<'_
M?L#E___E(=4#T``@`*=T_;BGF@`!P.7__^+7N10`&;D$`&+CL/"H`"3C$/"@
M`"3`4````NJY!`!'P#````./N00`*,#E___E<*?T_]+$&```-5.Y!`!7XT"@
M```$P#````.)XR`0```$P.7__^1]I_3\4^V`\?`(9>V@\?@(9>W`\@`(9>W@
M\@@(9>-`\H`(!.MO\D`(!`?T!P?K?_`X`"3C\/]@_W'$N```-4+C(+```!;`
MY?__Y2BY!`"BXR"P```6P.7__^4@T@"@N2"XP"````*MP.7___0C["@`"P!\
ME3$@`*=T``:5`"`!IX0`!<#E___Y5<08```U&N,@$```%L#E___E`*=9``NG
M20`!P#````-JP.7__^-F["8`40!\Q*@``#4$XR"@```6P.7__^3JIUD``Z=)
M``'`,````U?`Y?__XU"Y!`"R["8`N@!\Q)@``#3LXR"0```6P.7__^32IUD`
M`Z=)``'`,````T/`Y?__XSBY!`"R["@`[0!\P"````(XP.7___/)N00`HNPH
M`,0`?.,@D```%L#E___DLN,0L!``!+D$`$KC,!````3`Y?__XS>G]`#.XQ`@
M$``$IZ@``.-P$"@`!.RZ``$`V,:]```],Z>D`!G$B```-*;C((```!;`Y?__
MY(RG60``N10`2KD$`#?`Y?__XA.Y!`"2["8`)`!\Q!T``#T7IQK__^RA_X9@
M=J>X``'&O0``/0VGI/]^Q!@``#2`XR`0```6I[H``<#E___D9+D$`#?`Y?__
MX1^G]/_KQ!@``#SRN10`NZ<X!`#KNP`#``WCNQ````3C$"````18(!`,P"L`
M(`0`[",`$F!VXR`0$``$IP@``+)=`"NG%/_^IW3_OJ>J``&G]/^;XR"````6
MP.7__^0PIUD``J=)``#C,)````3`Y?__Y&:G]/_DXR"@```6P.7__^0>XQ"P
M$``$P$````*-XS`0```$P.7__^*BXQ"P$``$XQ`0```$D4`0#:>$_R_C(*``
M`!;`Y?__Y`+C$+`0``3C,!````3`Y?__X:FG]/\>P.7___8,N00`HN,@D```
M%NRH`%\`?,#E___CZ>,0L!``!+D$`$KC,!````3`Y?__XFZY!``JP.7__^.9
MQ+@``#/JXR"P```6P.7__^/0N00`HN,@L```%L#E___CR*=)``'`,````CS`
MY?__X+#`0````D&Y!``RN00`*L#E___B1N,@L```%L#E___CL)(`(+G`(```
M`1[`Y?__\K3$*P``/$7L)@`C`'S$*```/#?`Y?__^6S$*P``/#GL)@`7`'S`
M(````AK`Y?__X,#`Y?__XXW$.```/"+C$+`0``3C0#````2G]/[7ISD!P,0H
M```\'<#E___C*NPH`!H1?NP2``$`V.P<`!0!?\08```\!KD$`%+$2```/`GC
M,!````3`(````?O`Y?__X)#C0/$0``3K?_#8``0']`<'!P?KK_!0`"3C\/]@
M_W&Y!`"RP.7___<`P.7___;IN00`HL#E___X7.PH`!T`?NRX`!H`?)4`L`"G
MA``5P#````$FN00`*L#E___A@NRB``M@9+D$`"OKK_#P``3`]/__\^?C0/$0
M``3KK_#P``0']`<'Z[_P6``DX_#_8/]QP+```#$JXQ"P```$[!8`"O]\XT#Q
M$``$Z[_P^``$!_0-X>.PO_C_<:?T_^_K[_!P`"3C\/]@_W'C0/$0``3K[_$0
M``0']`<'!P<'!^OO\'``)+D$``^G^_]@XP#P```DP.7__^3NZ^_Q$``$!_X`
M`````````````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M```````````````1`````!__________<&5R;'AS:2YC`````````"X`+BX`
M`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z
M.E!!4CHZ0D]/5```97AE`"]P<F]C+R5I+R5S`%!!4E]414U0``!005)?4%)/
M1TY!344``#H`+P!015),-4Q)0@``4$523$Q)0@!015),-4]05```4$523$E/
M``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$
M14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P``4$%27T=,3T)!3%]4
M35!$25(`4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?
M0TQ%04X``%!!4E]#3$5!3CT``#$`3$1?3$E"4D%265]0051(`%-94U1%30``
M)3`R>```<&%R+0``)7,E<R5S)7,``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``'!A<FP``"YP
M87(``"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U
M+25U)7,``%!!5$@``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U
M;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T
M:6]N*0H``"]T;7```%1%35!$25(`5$U0`%5315(``%5315).04U%``!!4D=6
M```8`'!E<FP``#``4$%2.CI086-K97(Z.E9%4E-)3TX``#$N,#0U`%5N86)L
M92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*```M90``+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE
M;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE
M+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U
M:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN
M("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H
M("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D
M<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R
M)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T
M;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P
M9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT
M("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D
M;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=
M.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE
M"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T
M;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO
M9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO
M=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@
M8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI)
M;G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@
M("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@
M("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE
M)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@
M/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T
M96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("13
M24=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA
M;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]
M("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ
M.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S
M:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I
M;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(
M+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G
M;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R
M:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@
M?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*
M)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E
M="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&
M2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@
M)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H
M<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ
M+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A
M;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N
M86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN
M960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@
M)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA
M;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2![
M"F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L
M"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@
M>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO
M9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U
M:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK
M97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%
M)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[
M4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D
M92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L
M(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?
M=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M/GMB
M=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N
M)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@
M)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD
M("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@
M*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[
M)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F
M:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]
M"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET
M96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F
M:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"([
M"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,[
M"FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L
M971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA
M>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%
M3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E
M<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]
M('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN
M<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H
M0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'
M5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@
M>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI
M;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=
M*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O
M7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B
M.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D
M,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@
M)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2![
M"B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F
M:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B
M.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS
M:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!0
M05(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]
M"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2![
M"GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@
M)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D[
M"F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G
M)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E
M;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E
M;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD
M;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N
M*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I
M('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN
M;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S
M<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`[
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@
M*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E
M:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A
M)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R
M96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF
M;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D
M96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]
M?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y
M*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A
M;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N
M("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD
M9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@
M>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I
M;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S
M:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A
M;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#
M.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L
M7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D
M0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H
M("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E
M86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H
M+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I
M(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO
M*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO
M9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE
M*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT
M(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D
M+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@
M)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N
M=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT[
M"GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T
M(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\
M1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL
M=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL
M92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F
M:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L
M($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*
M*2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*
M)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA
M;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H
M95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE
M=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI6
M15)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@
M)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L
M(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM
M>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@
M)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<
M,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N
M/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F
M:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U
M-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T
M7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*
M<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF
M:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%
M35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R
M96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D
M;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E
M<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>
M"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD
M0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@
M)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF
M("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S
M<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@
M96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B
M)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D
M97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@
M(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C
M+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@
M<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]
M($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D
M<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE
M+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ
M;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S
M('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L
M:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U
M:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR
M97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R
M;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<[
M"G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V
M86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE
M=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@
M07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ
M2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@
M<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X
M('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?
M=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@
M)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@
M5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S
M(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@
M)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U
M:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ
M3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64[
M"GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I
M9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.
M5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<[
M"FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP
M86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII
M9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R
M;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D[
M"G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII
M9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES
M<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q
M.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`]
M(&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H
M85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG
M*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*
M?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M
M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S
M92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC
M;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?
M5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0[
M"GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N
M86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B
M)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@
M)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L
M("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B
M.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H
M.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E
M;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M
M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92![
M"FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O
M9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P
M<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@
M<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO
M<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F
M:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G
M;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY
M("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!
M5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER
M(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI
M;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA
M;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II
M9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@
M7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]0
M4D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM
M?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W
M9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN
M,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE
M(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF
M:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*
M?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:
M141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE4
M24%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$
M14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@
M)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM
M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.
M?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG
M=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@
M/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@
M:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B([
M"GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E
M<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@
M0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I
M.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M
M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI]
M.PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@````$;`SL```"\
M````%O__AS````3<__^+J````-C__Z.P```!%/__I&@```%0__^DP````7#_
M_Z5@```!H/__I]````'<__^I.````A3__ZG@```"0/__JB````)@__^J@```
M`IS__ZN8```"V/__JZ````+L__^MD````RC__ZVX```#//__KN@```-@__^P
M@````X3__[#X```#L/__L3@```/4__^Q\```!"#__[OH```$:/__OZ@```2@
M`````````!0``````7I2``%X#@$;#`^@`0```````#@````<__^*R```&`8`
M6(8.APV(#(D+B@J+"8P(C0>.!H\%1@[0!P,7YL_.S<S+RLG(Q\8.H`$`````
M`#@```!8__^BE````+8`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[``@**"L_.
MS<S+RLG(Q\8.H`%""P```!P```"4__^C$````%8`5(X&CP5&#M`">L_.#J`!
M````+````+3__Z-(````F@!*B@J+"8P(C0>.!H\%1@[0`@*(S\[-S,O*#J`!
M````````.````.3__Z.X```";`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5,#M`"
M`P)8S\[-S,O*R<C'Q@Z@`0``````-````2#__Z7L```!:`!*APV(#(D+B@J+
M"8P(C0>.!H\%1@[8`P,!5L_.S<S+RLG(QPZ@`0`````H```!6/__IQP```"D
M`%2+"8P(C0>.!H\%1@[8`P*(S\[-S,L.H`$``````!P```&$__^GF````#P`
M3(X&CP5&#L`"9,_.#J`!````.````:3__Z>X````8`!&A@Z'#8@,B0N*"HL)
MC`B-!XX&CP5&#L@"`E+/SLW,R\K)R,?&#J`!````````.````>#__Z?<```!
M&`!*A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M!"`P$&S\[-S,O*R<C'Q@Z@`0``
M````$````AS__ZBX````!@`````````X```",/__J*P```'L`$J&#H<-B`R)
M"XH*BPF,"(T'C@:/!48.X",#`=K/SLW,R\K)R,?&#J`!```````0```";/__
MJF`````B`````````"````*`__^J=````2P``OR.!H\%1@[``FC/S@Z@`0``
M`````"````*D__^K@````98`5(X&CP5&#O`"`P%ZS\X.H`$``````"@```+(
M__^L]````'(`6HX&CP5&#L`"`D`*S\X.H`%""T@.H`'.SP``````(````O3_
M_ZU`````.@!&C@:/!48.P`)D"L_.#J`!0@L`````2````QC__ZU<````L@!&
MA@Z'#8@,B0N*"HL)C`B-!XX&CP5*#L`";@K/SLW,R\K)R,?&#J`!1@L";,_.
MS<S+RLG(Q\8.H`$``````$0```-D__^MR```"?8`1H8.APV(#(D+B@J+"8P(
MC0>.!H\%4`ZPA0)4F!B9%YH6FQ4#"<K/SLW,R\K)R,?&V]K9V`Z@`0```#0`
M``.L__^W>````[P`1H<-B`R)"XH*BPF,"(T'C@:/!48.P`(#`Z[/SLW,R\K)
MR,<.H`$`````.````^3__[L`````;@!&B@J+"8P(C0>.!H\%1@[``@)."L_.
MS<S+R@Z@`48+3,_.S<S+R@Z@`0``````/```!"#__X),```"3`!&A@Z'#8@,
MB0N*"HL)C`B-!XX&CP5,#M@"`P(0"L_.S<S+RLG(Q\8.H`%""P``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````/______
M____``````````#__________P```````````````````````````````0``
M```````!``````````$````````"U0`````````/````````!$(`````````
M#````````!BH``````````T```````!9L`````!O__[U`````````A@`````
M````!0````````P(``````````8````````"V``````````*````````!&``
M````````"P`````````8`````````!4````````````````````#````````
MO8```````````@````````6@`````````!0`````````!P`````````7````
M````$P@`````````!P```````!!H``````````@````````"H``````````)
M`````````!@`````````&````````````````&____L`````"````0````!O
M___Y``````````X`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````+O@`````````````````````````````!C^````````&1X`````
M```9/@```````!E>````````&7X````````9G@```````!F^````````&=X`
M```````9_@```````!H>````````&CX````````:7@```````!I^````````
M&IX````````:O@```````!K>````````&OX````````;'@```````!L^````
M````&UX````````;?@```````!N>````````&[X````````;W@```````!O^
M````````'!X````````</@```````!Q>````````''X````````<G@``````
M`!R^````````'-X````````<_@```````!T>````````'3X````````=7@``
M`````!U^````````'9X````````=O@```````!W>````````'?X````````>
M'@```````!X^````````'EX````````>?@```````!Z>````````'KX`````
M```>W@```````![^````````'QX````````?/@```````!]>````````'WX`
M```````?G@```````!^^````````']X````````?_@```````"`>````````
M(#X````````@7@```````"!P`````````````````````````````%FP````
M````````````````````````````````````&*@`````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#``````````%Q0````````6B@`````````````
M`````%L4````````6Q@```````!<5@```````%IZ````````7%X`````````
M`````````%QB````````7&@``````````/____\`````````````70I'0T,Z
M("A!;'!I;F4@-BXT+C`I(#8N-"XP```N<VAS=')T86(`+FEN=&5R<``N9VYU
M+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN
M:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M
M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S
M`"YC;VUM96YT````````````````````````````````````````````````
M```````````````````````````````````````````````````+`````0``
M```````"`````````@`````````"```````````8````````````````````
M`0``````````````$V____8``````````@````````(8`````````A@`````
M````O`````,```````````````@``````````````!T````+``````````(`
M```````"V`````````+8````````"3`````$`````@`````````(````````
M`!@````E`````P`````````"````````#`@````````,"`````````1@````
M`````````````````0``````````````+0````0``````````@```````!!H
M````````$&@````````"H`````,```````````````@`````````&````#<`
M```$`````````$(````````3"````````!,(````````!:`````#````$@``
M```````(`````````!@```!!`````0`````````&````````&*@````````8
MJ``````````H`````````````````````@``````````````/`````$`````
M````!@```````!C0````````&-`````````'H`````````````````````0`
M````````(````$<````!``````````8````````@<````````"!P````````
M.4`````````````````````(``````````````!-`````0`````````&````
M````6;````````!9L``````````B`````````````````````@``````````
M````4P````$``````````@```````%G8````````6=@````````_9@``````
M``````````````@``````````````%L````!``````````(```````"90```
M`````)E``````````+P````````````````````$``````````````!I````
M`0`````````"````````F@````````":``````````1@````````````````
M````"```````````````<P````$``````````P```````+NX````````J[@`
M````````$`````````````````````@``````````````'H````!````````
M``,```````"[R````````*O(`````````!`````````````````````(````
M``````````"!`````0`````````#````````N]@```````"KV``````````(
M````````````````````"```````````````A@````8``````````P``````
M`+O@````````J^`````````!H`````0```````````````@`````````$```
M`(\````!``````````,```````"]@````````*V``````````H``````````
M```````````(``````````@```"4`````0`````````#````````P```````
M``"P``````````!X````````````````````"```````````````F@````@`
M`````````P```````,!X````````L'@````````0:```````````````````
M``@``````````````)\````!`````````#```````````````````+!X````
M`````!H````````````````````!``````````$````!`````P``````````
M``````````````````"PD@````````"H`````````````````````0``````
#````
